import chalk from 'chalk';
import program from 'commander';
import { readFileSync, writeFileSync } from 'fs';
import { join, parse } from 'path';
import importOpenApi from '../scripts/import-open-api';
const log = console.log; // tslint:disable-line:no-console
program.option('-o, --output [value]', 'output file destination');
program.option('-f, --file [value]', 'input file (yaml or json openapi specs)');
program.parse(process.argv);
const createSuccessMessage = (backend) => chalk.green(`${backend ? `[${backend}] ` : ''}🎉  Your OpenAPI spec has been converted into react query hooks`);
const successWithoutOutputMessage = chalk.yellow('Success! No output path specified; printed to standard output.');
const importSpecs = async (options) => {
    if (!options.file) {
        throw new Error("You need to provide an input specification with `--file`, '--url', or `--github`");
    }
    const data = readFileSync(join(process.cwd(), options.file), 'utf-8');
    const { ext } = parse(options.file);
    const format = ['.yaml', '.yml'].includes(ext.toLowerCase()) ? 'yaml' : 'json';
    return importOpenApi({
        data,
        format,
    });
};
// Use flags as configuration
importSpecs(program)
    .then((data) => {
    if (program.output) {
        writeFileSync(join(process.cwd(), program.output), data);
        log(createSuccessMessage());
    }
    else {
        log(data);
        log(successWithoutOutputMessage);
    }
})
    .catch((err) => {
    log(chalk.red(err));
    process.exit(1);
});
