"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.importSpecs = void 0;
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = require("fs");
const path_1 = require("path");
const import_open_api_1 = require("./import-open-api");
const log = console.log; // tslint:disable-line:no-console
const createSuccessMessage = (backend) => chalk_1.default.green(`🎉 ${backend ? `[${backend}] ` : ''} Your OpenAPI spec has been converted into react query hooks`);
function importSpecs({ sourceDirectory, exportDirectory, apiDirectory, queryClientDir, headerFilters, }) {
    (0, fs_1.readdir)(sourceDirectory, function (err, filenames) {
        if (err) {
            throw err;
        }
        filenames.map(async (filename) => {
            const data = (0, fs_1.readFileSync)((0, path_1.join)(process.cwd(), sourceDirectory + '/' + filename), 'utf-8');
            const { ext } = (0, path_1.parse)(sourceDirectory + '/' + filename);
            const format = ['.yaml', '.yml'].includes(ext.toLowerCase()) ? 'yaml' : 'json';
            try {
                const name = `useQueries${filename.split('.')[0]}.tsx`;
                const fileExports = await (0, import_open_api_1.importOpenApi)({
                    data,
                    format,
                    apiDirectory,
                    headerFilters,
                    queryClientDir,
                });
                (0, fs_1.writeFileSync)((0, path_1.join)(process.cwd(), `${exportDirectory}/${name}`), fileExports);
                log(createSuccessMessage(filename));
            }
            catch (error) {
                log(chalk_1.default.red(`[${filename}]:`), chalk_1.default.red(error));
                // process.exit(1);
            }
        });
    });
}
exports.importSpecs = importSpecs;
