import chalk from 'chalk';
import { readFileSync, writeFileSync, readdir } from 'fs';
import { join, parse } from 'path';
import { importOpenApi } from './import-open-api';
const log = console.log; // tslint:disable-line:no-console
const createSuccessMessage = (backend) => chalk.green(`🎉 ${backend ? `[${backend}] ` : ''} Your OpenAPI spec has been converted into react query hooks`);
export function importSpecs({ sourceDirectory, exportDirectory, apiDirectory, queryClientDir, headerFilters, }) {
    readdir(sourceDirectory, function (err, filenames) {
        if (err) {
            throw err;
        }
        filenames.map(async (filename) => {
            const data = readFileSync(join(process.cwd(), sourceDirectory + '/' + filename), 'utf-8');
            const { ext } = parse(sourceDirectory + '/' + filename);
            const format = ['.yaml', '.yml'].includes(ext.toLowerCase()) ? 'yaml' : 'json';
            try {
                const name = `useQueries${filename.split('.')[0]}.tsx`;
                const fileExports = await importOpenApi({
                    data,
                    format,
                    apiDirectory,
                    headerFilters,
                    queryClientDir,
                });
                writeFileSync(join(process.cwd(), `${exportDirectory}/${name}`), fileExports);
                log(createSuccessMessage(filename));
            }
            catch (error) {
                log(chalk.red(`[${filename}]:`), chalk.red(error));
                // process.exit(1);
            }
        });
    });
}
